@@ -22,7 +22,7 @@ test_that("gtsummary tables work with crr() output", {
 
   trial_contr <-
     trial
-  contrasts(trial_contr$grade) <-  contr.sum(3)
+  contrasts(trial_contr$grade) <- contr.sum(3)
   contrasts(trial_contr$stage) <-
     contr.treatment(attr(trial_contr$stage, "levels"), 3)
 
@@ -49,7 +49,7 @@ test_that("gtsummary tables work with crr() output", {
   )
   expect_equal(
     contr_treatment$table_body %>%
-      dplyr::filter(reference_row) %>%
+      filter(reference_row) %>%
       dplyr::pull(label),
     "T3",
     ignore_attr = TRUE
